@@ -1,6 +1,6 @@
 package Mojo::IRC::Server::Chinese;
 use strict;
-$Mojo::IRC::Server::Chinese::VERSION = "1.7.5";
+$Mojo::IRC::Server::Chinese::VERSION = "1.7.6";
 use Encode;
 use Encode::Locale;
 use Carp;
@@ -313,11 +313,10 @@ sub add_user{
         while(1){
             my $u = $s->search_user(nick=>$user->nick);
             if(defined $u){
-                if($nick =~/\((\d+)\)$/){
+                if($u->nick =~/\((\d+)\)$/){
                     my $num = $1;$num++;$user->nick($nick . "($num)");
                 }
                 else{$user->nick($nick . "(1)")}
-                #$user->send($user->ident,"433",$user->nick,$nick,'昵称已经被使用') 
             }
             else{last};
         }
